Attribute VB_Name = "Module1"
Option Explicit
Public intOldTabs() As Integer


'*************************************************
' Purpose: Show the form that sets the margins.
'*************************************************
Sub Menu_FilePageSetup()
    frmPageSetup.Show 1
End Sub


'*************************************************
' Purpose: Shows the credits
'*************************************************
Sub Menu_About()
    frmAboutForm.Show 1
End Sub



'*************************************************
' Purpose:  Copies the selected text to the clipboard.
'*************************************************
Sub Menu_CopyText()
    ' Sends CTRL-Insert to the control.
    ' This is Window's Copy key combination.
    SendKeys "^{INSERT}"
End Sub

'*************************************************
' Purpose:  Cuts the selected text to the clipboard.
'*************************************************
Sub Menu_CutText()
    ' Sends Shift-Del to the control.
    ' This is Window's CUT key combination.
    SendKeys "+{DEL}"
End Sub

'*************************************************
' Purpose:  Loads the form that finds text.
' Inputs:   mdiFrm:     The form that contains the
'                       RTF doc to operate on.
'           strSearch:  The text to find
' Returns:
'*************************************************
Sub Menu_EditFind(mdiFrm As Form, strSearch As String)
    Load frmFindForm 'load form
    frmFindForm.txtFind = strSearch 'set find text
    frmFindForm.Show 1 ' show modally
End Sub

'*************************************************
' Purpose:  Loads form to replace text
' Inputs:   mdiFrm:     The form that contains the
'                       RTF doc to operate on.
'           strSearch:  The text to find
' Returns:
'*************************************************
Sub Menu_EditReplace(mdiFrm As Form, strSearch As String)
    Load frmFindForm 'load form
    With frmFindForm
        .txtFind = strSearch 'set find text
        .txtReplace.Enabled = True 'enable replace
        .lblReplace.Enabled = True 'enable replace
        .Show 1 'show modally
    End With
End Sub


'*************************************************
' Purpose:  Save active RTF Doc to file.
' Effects:  May create a file on disk.
' Inputs:   mdiFrm:     The form that contains the
'                       RTF doc to operate on.
'           SaveAsName: Name to save file as (optional)
' Returns:  True on success
'           False on failure (or cancel)
'*************************************************
Function Menu_FileSave(mdiFrm As Form, Optional SaveAsName As Variant) As Boolean
    On Error GoTo CxlError3 'set error trap
    
    If IsMissing(SaveAsName) Then
        'if no save name specified
        If InStr(mdiFrm.Caption, "(untitled)") > 0 Then
            'if no previous name existed
            With frmMDIForm1.dlgCommonDialog1
                ' build default name and prompt
                .filename = "RTFDOC" & Right$(mdiFrm.Caption, 1) & ".RTF"
                .Filter = "Rich Text Files (*.rtf)|*.rtf"
                .Flags = cdlOFNOverwritePrompt
                .CancelError = True 'set error trigger
                ' show save file dialog
                .ShowSave
                ' set SaveAsName to dialog result
                SaveAsName = .filename
            End With
        Else
            ' set SaveAsName to the name that
            ' the file was already given
            SaveAsName = mdiFrm.Caption
        End If
    End If
    
    ' save file
    mdiFrm.rtfRichTextBox1.SaveFile CStr(SaveAsName)
    ' change the caption to reflect name
    mdiFrm.Caption = CStr(SaveAsName)
    ' set return value to true
    Menu_FileSave = True
    mdiFrm.rtfRichTextBox1.DataChanged = False
    Exit Function
CxlError3:
    ' set return value to false
    Menu_FileSave = False
    Exit Function
End Function

'*************************************************
' Purpose:  Align Text and update button images
' Inputs:   mdiFrm:     The form that contains the
'                       RTF doc to operate on.
'           intIndex:   The index of the button clicked.
'*************************************************
Sub Menu_FormatAlign(mdiFrm As Form, intIndex As Integer)
    With frmMDIForm1
        Select Case intIndex
            Case 0 'left
                'set images
                .imgAButtons(0).Picture = .ilsImageList1.ListImages("left_d").Picture
                .imgAButtons(1).Picture = .ilsImageList1.ListImages("center_u").Picture
                .imgAButtons(2).Picture = .ilsImageList1.ListImages("right_u").Picture
                'set alignment
                mdiFrm.rtfRichTextBox1.SelAlignment = rtfLeft
            Case 1 'center
                'set images
                .imgAButtons(0).Picture = .ilsImageList1.ListImages("left_u").Picture
                .imgAButtons(1).Picture = .ilsImageList1.ListImages("center_d").Picture
                .imgAButtons(2).Picture = .ilsImageList1.ListImages("right_u").Picture
                'set alignment
                mdiFrm.rtfRichTextBox1.SelAlignment = rtfCenter
            Case 2 'right
                'set images
                .imgAButtons(0).Picture = .ilsImageList1.ListImages("left_u").Picture
                .imgAButtons(1).Picture = .ilsImageList1.ListImages("center_u").Picture
                .imgAButtons(2).Picture = .ilsImageList1.ListImages("right_d").Picture
                'set alignment
                mdiFrm.rtfRichTextBox1.SelAlignment = rtfRight
        End Select
    End With
End Sub

'*************************************************
' Purpose:  Set the selected text to bold
' Inputs:   mdiFrm:     The form that contains the
'                       RTF doc to operate on.
'           vntForce:   True if the text should be
'                       forced into the specified
'                       attribute.
'                       False if it should be toggled.
'                       'Error 448' if it is not
'                       specified.  This is assumed
'                       to indicate false.
'*************************************************
Sub Menu_FormatBold(mdiFrm As Form, Optional vntForce As Variant)
    If IsMissing(vntForce) Then 'nothing specified
        vntForce = False
    End If
    
    With mdiFrm.rtfRichTextBox1
        If (IsNull(.SelBold) = True) Or (.SelBold = False) Or (vntForce = True) Then
            ' selection is mixed or not bold
            ' set it
            .SelBold = True
            frmMDIForm1.imgFButtons(0).Picture = frmMDIForm1.ilsImageList1.ListImages("bold_d").Picture
        ElseIf .SelBold = True Then
            ' selection is bold, toggle it
            .SelBold = False
            frmMDIForm1.imgFButtons(0).Picture = frmMDIForm1.ilsImageList1.ListImages("bold_u").Picture
        End If
    End With
End Sub

'*************************************************
' Purpose:  Inserts bullets into the selectd text.
' Inputs:   mdiFrm:     The form that contains the
'                       RTF doc to operate on.
'*************************************************
Sub Menu_FormatBullet(mdiFrm As Form)
    With mdiFrm.rtfRichTextBox1
        If (IsNull(.SelBullet) = True) Or (.SelBullet = False) Then
            ' selection is mixed or not bulleted
            ' so set it.
            .SelBullet = True
        ElseIf .SelBullet = True Then
            ' selection is bold, toggle it
            .SelBullet = False
            .SelHangingIndent = False
        End If
    End With
End Sub

'*************************************************
' Purpose:  Show form that sets the text color.
'*************************************************
Sub Menu_FormatColor()
    frmColor.Show 1
End Sub

'*************************************************
' Purpose:  Sets the selected text to italic.
' Inputs:   mdiFrm:     The form that contains the
'                       RTF doc to operate on.
'           vntForce:   True if the text should be
'                       forced into the specified
'                       attribute.
'                       False if it should be toggled.
'                       'Error 448' if it is not
'                       specified.  This is assumed
'                       to indicate false.
'*************************************************
Sub Menu_FormatItalic(mdiFrm As Form, Optional vntForce As Variant)
    If IsMissing(vntForce) Then 'nothing specified
        vntForce = False
    End If
    With mdiFrm.rtfRichTextBox1
        If (IsNull(.SelItalic) = True) Or (.SelItalic = False) Or (vntForce = True) Then
            ' selection is italic or mixed, so set italic
            .SelItalic = True
            frmMDIForm1.imgFButtons(1).Picture = frmMDIForm1.ilsImageList1.ListImages("italic_d").Picture
        ElseIf .SelItalic = True Then
            'selection is italic, so toggle it
            .SelItalic = False
            frmMDIForm1.imgFButtons(1).Picture = frmMDIForm1.ilsImageList1.ListImages("italic_u").Picture
        End If
    End With
End Sub

'*************************************************
' Purpose:  Show form that sets the alignment
'*************************************************
Sub Menu_FormatParagraph()
    frmParagraph.Show 1
End Sub

'*************************************************
' Purpose:  Underlines the selected text
' Inputs:   mdiFrm:     The form that contains the
'                       RTF doc to operate on.
'           vntForce:   True if the text should be
'                       forced into the specified
'                       attribute.
'                       False if it should be toggled.
'                       'Error 448' if it is not
'                       specified.  This is assumed
'                       to indicate false.
'*************************************************
Sub Menu_FormatUnderline(mdiFrm As Form, Optional vntForce As Variant)
    If IsMissing(vntForce) Then ' nothing specified
        vntForce = False
    End If
    With mdiFrm.rtfRichTextBox1
        If (IsNull(.SelUnderline) = True) Or _
            (.SelUnderline = False) Or (vntForce = True) Then
            ' selection is underlined or mixed,
            ' so set to underlined
            .SelUnderline = True
            frmMDIForm1.imgFButtons(2).Picture = frmMDIForm1.ilsImageList1.ListImages("underline_d").Picture
        ElseIf .SelUnderline = True Then
            'selection is not underlined,
            ' so toggle it.
            .SelUnderline = False
            frmMDIForm1.imgFButtons(2).Picture = frmMDIForm1.ilsImageList1.ListImages("underline_u").Picture
        End If
    End With
End Sub

'*************************************************
' Purpose:  Paste text from clipboard.
' Effects:  Replaces the selectd text
'*************************************************
Sub Menu_PasteText()
    ' Sends Shift-Insert to the control.
    ' This is Window's PASTE key combination.
    SendKeys "+{INSERT}"
End Sub

'*************************************************
' Purpose:  Unload Application
'*************************************************
Sub Menu_FileExit()
    Unload frmMDIForm1
    DoEvents
    'End
End Sub

'*************************************************
' Purpose:  Create New file.
'*************************************************
Sub Menu_FileNew()
    Dim mdiFrm As New mdiDocForm 'copy template
    ' give it a default title
    mdiFrm.Caption = "(untitled):" & Forms.Count
    ' show the form
    mdiFrm.Show
    ' set the flag to show the doc is clean.
    mdiFrm.rtfRichTextBox1.DataChanged = False
End Sub

'*************************************************
' Purpose:  Open RTF file on disk.
'*************************************************
Sub Menu_FileOpen()
    On Error GoTo CxlErr 'set error trap
    With frmMDIForm1.dlgCommonDialog1
        ' prep common dialog
        .Filter = "Rich Text File (*.rtf)|*.rtf"
        .CancelError = True
        'show common dialog
        .ShowOpen
        If UCase(Right(.filename, 4)) <> ".RTF" Then
            ' possibly not RTF file, prompt
            If MsgBox("Do you want to open the file anyway?", _
                vbYesNo + vbQuestion, "This May Not Be A Rich Text File") _
                = vbNo Then
                Exit Sub
            End If
        End If
        Dim mdiFrm As New mdiDocForm 'create new form for file
        mdiFrm.rtfRichTextBox1.Visible = False
        mdiFrm.Caption = .filename 'set caption
        ' open file
        mdiFrm.rtfRichTextBox1.LoadFile frmMDIForm1.dlgCommonDialog1.filename
        If (.Flags And cdlOFNReadOnly) <> 0 Then
            ' if opened read-only, lock it.
            mdiFrm.rtfRichTextBox1.Locked = True
        End If
        ' let the OS catch up
        DoEvents
        mdiFrm.rtfRichTextBox1.DataChanged = False
        mdiFrm.rtfRichTextBox1.Visible = True
    End With
CxlErr: 'cancel pressed
    Exit Sub
End Sub



'*************************************************
' Purpose:  Print the formatted contents of the
'           active RTF control.
' Inputs:   mdiFrm:     The form that contains the
'                       RTF doc to operate on.
'*************************************************
Sub Menu_FilePrint(mdiFrm As Form)
    On Error GoTo cxlError8 ' set error trap
    With frmMDIForm1.dlgCommonDialog1
        ' set up printer common dialog
        .Flags = cdlPDReturnDC + cdlPDNoPageNums
        .CancelError = True
        If mdiFrm.rtfRichTextBox1.SelLength = 0 Then
            .Flags = .Flags + cdlPDAllPages
        Else
            .Flags = .Flags + cdlPDSelection
        End If
        ' show printer dialog
        .ShowPrinter
        If (.Flags And cdlPDSelection) <> 0 Then
            ' print selection was selected
            If mdiFrm.rtfRichTextBox1.SelLength <> 0 Then
                mdiFrm.rtfRichTextBox1.SelPrint .hDC
            End If
        Else
            ' print all was selected
            mdiFrm.rtfRichTextBox1.SelLength = 0
            mdiFrm.rtfRichTextBox1.SelPrint .hDC
        End If
    End With
cxlError8: 'cancel pressed
    Exit Sub
End Sub



'*************************************************
' Purpose:  Update buttons and fonts on the toolbar
' Inputs:   mdiFrm:     The form that contains the
'                       RTF doc to operate on.
'*************************************************
Sub UpdateTextInfo(mdiFrm As Form)
    Static fLast As String 'font
    Static sLast As String 'font size
    With frmMDIForm1
        ' update bold button
        If mdiFrm.rtfRichTextBox1.SelBold Then
            .imgFButtons(0).Picture = .ilsImageList1.ListImages("bold_d").Picture
        Else
            .imgFButtons(0).Picture = .ilsImageList1.ListImages("bold_u").Picture
        End If
        
        ' update italic button
        If mdiFrm.rtfRichTextBox1.SelItalic Then
            .imgFButtons(1).Picture = .ilsImageList1.ListImages("italic_d").Picture
        Else
            .imgFButtons(1).Picture = .ilsImageList1.ListImages("italic_u").Picture
        End If
        
        ' update underline button
        If mdiFrm.rtfRichTextBox1.SelUnderline Then
            .imgFButtons(2).Picture = .ilsImageList1.ListImages("underline_d").Picture
        Else
            .imgFButtons(2).Picture = .ilsImageList1.ListImages("underline_u").Picture
        End If
        
        ' update alignment buttons
        Select Case mdiFrm.rtfRichTextBox1.SelAlignment
            Case Null
                .imgAButtons(0).Picture = .ilsImageList1.ListImages("left_u").Picture
                .imgAButtons(1).Picture = .ilsImageList1.ListImages("center_u").Picture
                .imgAButtons(2).Picture = .ilsImageList1.ListImages("right_u").Picture
            Case rtfLeft
                .imgAButtons(0).Picture = .ilsImageList1.ListImages("left_d").Picture
                .imgAButtons(1).Picture = .ilsImageList1.ListImages("center_u").Picture
                .imgAButtons(2).Picture = .ilsImageList1.ListImages("right_u").Picture
            Case rtfCenter
                .imgAButtons(0).Picture = .ilsImageList1.ListImages("left_u").Picture
                .imgAButtons(1).Picture = .ilsImageList1.ListImages("center_d").Picture
                .imgAButtons(2).Picture = .ilsImageList1.ListImages("right_u").Picture
            Case rtfRight
                .imgAButtons(0).Picture = .ilsImageList1.ListImages("left_u").Picture
                .imgAButtons(1).Picture = .ilsImageList1.ListImages("center_u").Picture
                .imgAButtons(2).Picture = .ilsImageList1.ListImages("right_d").Picture
        End Select
        
        Dim blnFound As Boolean 'found flag
        Dim intI As Integer ' counter
        If fLast <> mdiFrm.rtfRichTextBox1.SelFontName Then
            ' find current font, and display name
            For intI = 0 To .cboFontCombo.ListCount - 1
                If .cboFontCombo.List(intI) = mdiFrm.rtfRichTextBox1.SelFontName Then
                    .cboFontCombo.ListIndex = intI
                    intI = .cboFontCombo.ListCount
                    blnFound = True
                End If
            Next intI
            If blnFound = True Then
                fLast = mdiFrm.rtfRichTextBox1.SelFontName
            Else
                ' if font name not found, show nothing
                fLast = ""
                .cboFontCombo.ListIndex = -1
            End If
        End If
        
        ' find font size in list
        If sLast <> mdiFrm.rtfRichTextBox1.SelFontSize Then
            If Val(mdiFrm.rtfRichTextBox1.SelFontSize) <= 70 And Val(mdiFrm.rtfRichTextBox1.SelFontSize) >= 6 Then
                .cboSizeCombo.ListIndex = Val(mdiFrm.rtfRichTextBox1.SelFontSize) - 6
            Else
                .cboSizeCombo.ListIndex = -1
            End If
            sLast = mdiFrm.rtfRichTextBox1.SelFontSize
        End If
    End With
End Sub


